/*
 * @(#)LogRedirect.java	1.0 03/05/2002
 * 
 * Copyright (c) 2000-2002 Jake Howlett, codestore.net
 */

import javax.servlet.*;
import javax.servlet.http.*;

import java.io.IOException;

import lotus.domino.*;
import java.util.Date;
import java.text.DateFormat;

/**
 * A basic redirect servlet.  Given a single destination, 
 * it will redirect the browser to it and create an entry
 * in a Domino database to record the movement.
 *
 * Example: http://dominoserver/servlet/LogRedirect?location=http://otherdominoserver/
 */
public class LogRedirect extends HttpServlet { 

    private final static String sLogDBServer    =   "";
    private final static String sLogDBPath      =   "apps/redirect.nsf";
    
    /**
    * Given a request with a QueryString parameter called location, redirect
    */ 
    public void service(HttpServletRequest req, HttpServletResponse res)
    throws ServletException, IOException
    {
        String goTo = req.getParameter("location");

        if ( goTo == null ) {
            res.sendError(res.SC_INTERNAL_SERVER_ERROR, "Error - redirect destination unspecified."
                + "Make sure that there is a parameter called location in the Query_String!");
            return;
        }
        
        res.sendRedirect( goTo );
        logIt( goTo );
    }

/**
 * Obtain information on this servlet.
 * @return String describing this servlet.
 */
    public String getServletInfo() {
        return "Redirect and Log Domino servlet -- used to send redirects and record them";
    }
    
    /**
    * Create a Domino document that records the movement
    */
    private void logIt( String goToURI ) {
        
        Date now = new Date();
        DateFormat df = DateFormat.getDateTimeInstance( DateFormat.MEDIUM, DateFormat.MEDIUM );
        NotesThread nThread = new NotesThread();
        Session s = null;
    
        try {
            nThread.sinitThread();
            s = NotesFactory.createSession();
      
            Database db = s.getDatabase( sLogDBServer, sLogDBPath );
            
            if ( db == null ) {
                System.out.println("Servlet Error - \"LogRedirect\": Error opening database - " + sLogDBServer + ":" + sLogDBPath );
            } else {
                
                Document doc = db.createDocument();
                doc.replaceItemValue( "Form", "Log" );
                doc.replaceItemValue( "Date", df.format( now ) );
                doc.replaceItemValue( "Path", goToURI );
                doc.save( true );
            }
            
        } catch (NotesException ne) {
            ne.printStackTrace();
        } finally {
            try {
                s.recycle();
            } catch (Exception e){
                e.printStackTrace();
            }
            nThread.stermThread();
    	}
    }
}